@@ -28,6 +28,7 @@ from .literals import (
     PrincipalTypeType,
     ResourceSortTypeType,
     ResourceStateTypeType,
+    SubscriptionProtocolTypeType,
     UserFilterTypeType,
     UserSortTypeType,
     UserTypeType,
@@ -251,7 +252,7 @@ class WorkDocsClient(BaseClient):
         *,
         OrganizationId: str,
         Endpoint: str,
-        Protocol: Literal["HTTPS"],
+        Protocol: SubscriptionProtocolTypeType,
         SubscriptionType: Literal["ALL"]
     ) -> CreateNotificationSubscriptionResponseTypeDef:
         """
@@ -328,6 +329,21 @@ class WorkDocsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#delete_document)
         """
 
+    def delete_document_version(
+        self,
+        *,
+        DocumentId: str,
+        VersionId: str,
+        DeletePriorVersions: bool,
+        AuthenticationToken: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        Deletes a version of an Amazon WorkDocs document.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workdocs.html#WorkDocs.Client.delete_document_version)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#delete_document_version)
+        """
+
     def delete_folder(
         self, *, FolderId: str, AuthenticationToken: str = ...
     ) -> EmptyResponseMetadataTypeDef:
@@ -643,14 +659,14 @@ class WorkDocsClient(BaseClient):
     def initiate_document_version_upload(
         self,
         *,
-        ParentFolderId: str,
         AuthenticationToken: str = ...,
         Id: str = ...,
         Name: str = ...,
         ContentCreatedTimestamp: Union[datetime, str] = ...,
         ContentModifiedTimestamp: Union[datetime, str] = ...,
         ContentType: str = ...,
-        DocumentSizeInBytes: int = ...
+        DocumentSizeInBytes: int = ...,
+        ParentFolderId: str = ...
     ) -> InitiateDocumentVersionUploadResponseTypeDef:
         """
         Creates a new document object and version object.
@@ -684,6 +700,16 @@ class WorkDocsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#remove_resource_permission)
         """
 
+    def restore_document_versions(
+        self, *, DocumentId: str, AuthenticationToken: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        Recovers a deleted version of an Amazon WorkDocs document.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workdocs.html#WorkDocs.Client.restore_document_versions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#restore_document_versions)
+        """
+
     def update_document(
         self,
         *,
