@@ -128,7 +128,7 @@ RolePermissionTypeType = Literal["DIRECT", "INHERITED"]
 RoleTypeType = Literal["CONTRIBUTOR", "COOWNER", "OWNER", "VIEWER"]
 ShareStatusTypeType = Literal["FAILURE", "SUCCESS"]
 StorageTypeType = Literal["QUOTA", "UNLIMITED"]
-SubscriptionProtocolTypeType = Literal["HTTPS"]
+SubscriptionProtocolTypeType = Literal["HTTPS", "SQS"]
 SubscriptionTypeType = Literal["ALL"]
 UserFilterTypeType = Literal["ACTIVE_PENDING", "ALL"]
 UserSortTypeType = Literal["FULL_NAME", "STORAGE_LIMIT", "STORAGE_USED", "USER_NAME", "USER_STATUS"]
@@ -383,6 +383,7 @@ ServiceName = Literal[
     "redshift-serverless",
     "rekognition",
     "resiliencehub",
+    "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -403,6 +404,7 @@ ServiceName = Literal[
     "sagemaker-featurestore-runtime",
     "sagemaker-runtime",
     "savingsplans",
+    "scheduler",
     "schemas",
     "sdb",
     "secretsmanager",
