@@ -34,6 +34,7 @@ from .literals import (
     RoleTypeType,
     ShareStatusTypeType,
     StorageTypeType,
+    SubscriptionProtocolTypeType,
     UserFilterTypeType,
     UserSortTypeType,
     UserStatusTypeType,
@@ -70,6 +71,7 @@ __all__ = (
     "DeleteCommentRequestRequestTypeDef",
     "DeleteCustomMetadataRequestRequestTypeDef",
     "DeleteDocumentRequestRequestTypeDef",
+    "DeleteDocumentVersionRequestRequestTypeDef",
     "DeleteFolderContentsRequestRequestTypeDef",
     "DeleteFolderRequestRequestTypeDef",
     "DeleteLabelsRequestRequestTypeDef",
@@ -100,6 +102,7 @@ __all__ = (
     "RemoveAllResourcePermissionsRequestRequestTypeDef",
     "RemoveResourcePermissionRequestRequestTypeDef",
     "ResourcePathComponentTypeDef",
+    "RestoreDocumentVersionsRequestRequestTypeDef",
     "UpdateDocumentRequestRequestTypeDef",
     "UpdateDocumentVersionRequestRequestTypeDef",
     "UpdateFolderRequestRequestTypeDef",
@@ -368,7 +371,7 @@ CreateNotificationSubscriptionRequestRequestTypeDef = TypedDict(
     {
         "OrganizationId": str,
         "Endpoint": str,
-        "Protocol": Literal["HTTPS"],
+        "Protocol": SubscriptionProtocolTypeType,
         "SubscriptionType": Literal["ALL"],
     },
 )
@@ -378,7 +381,7 @@ SubscriptionTypeDef = TypedDict(
     {
         "SubscriptionId": str,
         "EndPoint": str,
-        "Protocol": Literal["HTTPS"],
+        "Protocol": SubscriptionProtocolTypeType,
     },
     total=False,
 )
@@ -482,6 +485,30 @@ class DeleteDocumentRequestRequestTypeDef(
     pass
 
 
+_RequiredDeleteDocumentVersionRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteDocumentVersionRequestRequestTypeDef",
+    {
+        "DocumentId": str,
+        "VersionId": str,
+        "DeletePriorVersions": bool,
+    },
+)
+_OptionalDeleteDocumentVersionRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteDocumentVersionRequestRequestTypeDef",
+    {
+        "AuthenticationToken": str,
+    },
+    total=False,
+)
+
+
+class DeleteDocumentVersionRequestRequestTypeDef(
+    _RequiredDeleteDocumentVersionRequestRequestTypeDef,
+    _OptionalDeleteDocumentVersionRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredDeleteFolderContentsRequestRequestTypeDef = TypedDict(
     "_RequiredDeleteFolderContentsRequestRequestTypeDef",
     {
@@ -959,14 +986,8 @@ GetResourcesRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredInitiateDocumentVersionUploadRequestRequestTypeDef = TypedDict(
-    "_RequiredInitiateDocumentVersionUploadRequestRequestTypeDef",
-    {
-        "ParentFolderId": str,
-    },
-)
-_OptionalInitiateDocumentVersionUploadRequestRequestTypeDef = TypedDict(
-    "_OptionalInitiateDocumentVersionUploadRequestRequestTypeDef",
+InitiateDocumentVersionUploadRequestRequestTypeDef = TypedDict(
+    "InitiateDocumentVersionUploadRequestRequestTypeDef",
     {
         "AuthenticationToken": str,
         "Id": str,
@@ -975,18 +996,11 @@ _OptionalInitiateDocumentVersionUploadRequestRequestTypeDef = TypedDict(
         "ContentModifiedTimestamp": Union[datetime, str],
         "ContentType": str,
         "DocumentSizeInBytes": int,
+        "ParentFolderId": str,
     },
     total=False,
 )
 
-
-class InitiateDocumentVersionUploadRequestRequestTypeDef(
-    _RequiredInitiateDocumentVersionUploadRequestRequestTypeDef,
-    _OptionalInitiateDocumentVersionUploadRequestRequestTypeDef,
-):
-    pass
-
-
 UploadMetadataTypeDef = TypedDict(
     "UploadMetadataTypeDef",
     {
@@ -1060,6 +1074,28 @@ ResourcePathComponentTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredRestoreDocumentVersionsRequestRequestTypeDef = TypedDict(
+    "_RequiredRestoreDocumentVersionsRequestRequestTypeDef",
+    {
+        "DocumentId": str,
+    },
+)
+_OptionalRestoreDocumentVersionsRequestRequestTypeDef = TypedDict(
+    "_OptionalRestoreDocumentVersionsRequestRequestTypeDef",
+    {
+        "AuthenticationToken": str,
+    },
+    total=False,
+)
+
+
+class RestoreDocumentVersionsRequestRequestTypeDef(
+    _RequiredRestoreDocumentVersionsRequestRequestTypeDef,
+    _OptionalRestoreDocumentVersionsRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredUpdateDocumentRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateDocumentRequestRequestTypeDef",
     {
